import random
from urllib.parse import urlparse
from . import settings


def get_uri(uri, base):
    return '{}{}'.format(base, uri)


def get_base_url(origin):
    url = urlparse(origin)  # type: ParseResult
    return url.scheme + "://" + url.netloc + '/'


def patch_header(session):
    session.headers.update(settings.DEFAULT_HEADERS)


def random_ip(session):
    _ip = '116.118.{}.{}'.format(random.randrange(200), random.randrange(200))
    session.headers.update({
        'X-Forwarded-For': _ip
    })



import os

DEFAULT_HEADERS = {
    'Accept-Language': 'en-US,en;q=0.5',
    'Accept-Encoding': 'gzip, deflate, sdch',
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
    'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6) '
                  'AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.110 Safari/537.36',
}

WIN_LOSE_MONGODB_URL = os.getenv('WIN_LOSE_MONGODB_URL', os.getenv('MONGODB_URL', ''))
TICKET_MONGODB_URL = os.getenv('TICKET_MONGODB_URL', os.getenv('MONGODB_URL', ''))



"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'cc-agent-helper'
__description__ = 'agent helper package'
__version__ = '0.0.1'
__author__ = 'Cockroach Creative'
__author_email__ = 'support@cockreative.com'
__license__ = 'Apache 2.0'
__url__ = 'https://cockreative.com/'



#!/usr/bin/env python3

import os
from setuptools import setup

# get key package details from py_pkg/__version__.py
about = {}  # type: ignore
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'api_helper', '__version__.py')) as f:
    exec(f.read(), about)

# load the README file and use it as the long_description for PyPI
with open('README.md', 'r') as f:
    readme = f.read()

# package configuration - for reference see:
# https://setuptools.readthedocs.io/en/latest/setuptools.html#id9
setup(
    name=about['__title__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    version=about['__version__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=['api_helper'],
    include_package_data=True,
    python_requires=">=3.7.*",
    install_requires=['pymongo',],
    license=about['__license__'],
    zip_safe=False,
    # entry_points={
    #     'console_scripts': ['py-package-template=py_pkg.entry_points:main'],
    # },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='agent-helper'
)


import logging

from itertools import chain, islice

from pymongo import MongoClient
import pymongo.errors

from . import settings

LOG = logging.getLogger(__name__)


def import_win_lose(data):
    if settings.WIN_LOSE_MONGODB_URL:
        with MongoClient(settings.WIN_LOSE_MONGODB_URL) as connection:
            db = connection.bookmaker
            db.win_lose.replace_one({'uuid': data.get('uuid')}, data, upsert=True)
    else:
        LOG.info(data)
    return data.get('username')


def chunks(iterable, size=10):
    iterator = iter(iterable)
    for first in iterator:
        yield chain([first], islice(iterator, size - 1))


def ticket_filter(x):
    # check sport type
    if x.get('sport') not in ['football', 'soccer']:
        return False
    #
    # # reject virtual sport
    # home_team = x.get('home_team', '')
    #
    # # sbobet virtual
    # if home_team.startswith('e-'):
    #     return False
    #
    # # ibet pingoal
    # if '(pg)' in home_team:
    #     return False
    #
    # # ibet virtual
    # if '(v)' in home_team:
    #     return False

    return True


def import_ticket(ticket_iterator, username, from_date, to_date):
    total_tickets = 0
    ticket_filtered = filter(ticket_filter, ticket_iterator)
    with MongoClient(settings.TICKET_MONGODB_URL) as connection:
        for tickets in chunks(ticket_filtered, 100):
            collector = [dict(ticket, _id=ticket.get('uuid')) for ticket in tickets]
            total_tickets += len(collector)
            if settings.TICKET_MONGODB_URL:
                try:
                    connection.bookmaker.tickets.insert_many(collector, ordered=False)
                except pymongo.errors.BulkWriteError:
                    pass
            LOG.info('{} Processed {} tickets'.format(username, total_tickets))
        uuid = '__'.join([username, from_date, to_date])
        summary = {
            '_id': uuid,
            'count': total_tickets,
            'username': username,
            'from_date': from_date,
            'to_date': to_date
        }

        connection.bookmaker.account_ticket_count.replace_one({'_id': uuid}, summary, upsert=True)

        return summary
